#!/bin/sh
#********************************************************************************
# (c) Copyright [2021] Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates 
# and licensors (“Micro Focus”) are as may be set forth in the express warranty 
# statements accompanying such products and services. Nothing herein should be 
# construed as constituting an additional warranty. Micro Focus shall not be liable 
# for technical or editorial errors or omissions contained herein. The information 
# contained herein is subject to change without notice.
#********************************************************************************

LP_USER=lp
PASSWD_FILE=/etc/passwd
ERR_LOG="/var/opt/novell/log/iprint_user_util.log"

isCluster() 
{
    IPRINT_NSS=$(grep Required-Start /opt/novell/iprint/init.d/novell-ipsmd | grep nss)
    if [ ! -z "${IPRINT_NSS}" ]; then
        return 1
    else
        return 0
    fi
}


isPoolRunningOnThisNode()
{
    MEDIA_DIR=$(readlink /etc/opt/novell/iprint/conf)
    TEST_FILE="$MEDIA_DIR/iprintconf.properties"
    if [ -f $TEST_FILE ]; then
        return 1
    else
        return 0
    fi
}


fixCupsUser()
{
	cat $PASSWD_FILE | grep "^lp:" > /dev/null 2>&1
	lp_user_status=$?
	if [ $lp_user_status -eq 0 ]; then 	#found local lp user, lets remove it
		systemctl status iprint-cups.service >> "${ERR_LOG}" 2>&1
		#stop CUPS only if running
		if [ $? -eq 0 ] ; then
			systemctl stop iprint-cups.service >> "${ERR_LOG}" 2>&1
		fi
		echo "A local $LP_USER user exists, trying to delete." >> "${ERR_LOG}"
		id "$LP_USER" >> "${ERR_LOG}" 2>&1	
		userdel_output=`userdel $LP_USER 2>&1`
		userdel_status=$?

		if [ $userdel_status -ne 0 ]; then
			echo "Local $LP_USER user deletion failed: $userdel_status, with following error" >> "${ERR_LOG}"
			echo $userdel_output >> "${ERR_LOG}"
		fi

		isPoolRunningOnThisNode
		if [[ $? -eq 1 ]]; then
			systemctl start iprint-cups.service >> "${ERR_LOG}" 2>&1
		fi
		
		#Let us do an id lp to refresh the NSCD cache
		id "$LP_USER" >> "${ERR_LOG}" 2>&1	
	fi
}


# Delete the local lp user in case of a cluster if it is present
# In case of cluster, LUM enabled lp user is used for the CUPS printing, so local lp user is not required & deleted
# Whenever there is a CUPS rpm update happens, the local lp user is recreated
# In this case the user needs to be deleted, so that LUM user is effective
isCluster
if [[ $? -eq 1 ]]; then
	fixCupsUser
fi
